.. _api-utils:

Utilities
=========

.. py:module:: altapay.utils

.. autofunction:: etree_to_dict

.. autofunction:: handle_xml_value

.. autofunction:: http_build_query

.. autofunction:: to_pythonic_name

.. autofunction:: to_pythonic_dict
